Object to store prob machines
nameindividual name
fCallFunction Call of the method. Possible is: "MVFOSM","FORM", "SORM", "MC_Crude", "MC_IS", "MC_SubSam"
optionsadditional options for the method provided as a list. For form e.g. options=list("optim_type"="rackfies"). To get insight of all available settings of each method open the help with ?FORM, ?SORM, ?MC_IS etc.